@@ -131,7 +131,7 @@ class objearth():
             secax_y.set_ylabel('latitute')
             plt.grid(color='w', linestyle='-', linewidth=0.15)
             plt.show()
-
+        #Area
         elif type(DataArray) == numpy.ndarray:
             if area==True:
                 ymax = 0 ; ymin = DataArray.shape[0]
@@ -144,8 +144,7 @@ class objearth():
             #plotshow
             plt.figure(figsize=(figsize))
             color_map = plt.imshow(real_margin_img,extent=[xmin,xmax,ymin,ymax])
-            if zenmode == False:
-                plt.imshow(DataArray[ymax:ymin,xmin:xmax],extent=[xmin,xmax,ymin,ymax])
+            if zenmode != True:
                 plt.title(title)
                 plt.xlabel(xlabel)
                 plt.ylabel(ylabel)
@@ -173,8 +172,9 @@ class objearth():
                 color_map.set_cmap(cmap)
             plt.colorbar(orientation="vertical",fraction=fac)
             plt.show()
+
         else:
-                print("Nonetype :",type(DataArray))
+            print("Nonetype :",type(DataArray))
             
 
     def percentcloud(self,Dataset):
